/* [General Dimensions] */
back_height = 45;
length = 76;
width = 54;
thickness = 8.5;
// Thickness of the base reinforcements
side_thickness = 6.5;
// Which if any mount style to include
include_qc_mount = "hicwic"; // [none, hicwic, vicious1] 

/* [Motor Mount Dimensions] */
motor_mount_width = 40;
motor_mount_height = 30;

/* [Motor Mount Holes] */
motor_mount_center_hole_radius = 4;
Motor_Bolt_X_spacing = 22; // Motor Bolts X distance
Motor_Bolt_Y_spacing = 22; // Motor Bolts Y distance
//Motor mount hole diameter
Screw_Size = 3.2; // Screw Size

/* [Needle Hole] */
needle_hole_radius = 3.5;
needle_hole_front_offset = 16;
needle_hole_mount_radius = 1.5;
needle_hole_mount_offset = 14.5;



// Small translation to make it look/plate nicer
translate([width/2,length/2,0]) rotate([0,0,180]) 
difference() {
    union() {
        // Base Plate
        cube([width,length,thickness]);
        // Back 
        translate([0,0,thickness]) {cube([width,thickness,back_height]);}
 
        // Motor Mount
            
        translate([(width-motor_mount_width)/2,0,back_height+thickness]) cube([motor_mount_width,thickness,motor_mount_height]);

        // Sides
        side();
        translate([width-side_thickness,0,0]) side();
    
        // QC mount
        if (include_qc_mount == "hicwic") {
            translate([0,-42,18.15]) union() {
                hw_qc_mini_mount(1);
                translate([18.75,30,-18.15]) cube([14.2,12,29.75]);
                if (back_height>43) {
                    translate([0,0,37]) resize([0,0,30], auto=[false,false,true]) hw_qc_mount_extension();
                }
            }
        }
        
    }
    // Needle hole
    translate([width/2,length-needle_hole_front_offset,thickness/2]) cylinder(h=thickness+2, r=needle_hole_radius, center=true);
    
    // Needle mount holes
    translate([(width/2)+needle_hole_mount_offset,length-needle_hole_front_offset,thickness/2]) cylinder(h=thickness+2, r=needle_hole_mount_radius, center=true);
    translate([(width/2)-needle_hole_mount_offset,length-needle_hole_front_offset,thickness/2]) cylinder(h=thickness+2, r=needle_hole_mount_radius, center=true);
    
    // Motor Center Hole
    translate ([width/2,thickness/2,back_height+(motor_mount_height/2)+thickness]) rotate([90,0,0]) cylinder(h=thickness+2, r=motor_mount_center_hole_radius, center=true);

    // Motor Mount Holes
    translate ([width/2,thickness/2,back_height+(motor_mount_height/2)+thickness]) rotate([90,0,0]) motor_screws(sl=thickness+2);    
}

module side() {
        difference() {
        cube([side_thickness,length,22]);
        translate([-1,3,23]) rotate([-12,0,0]) cube([side_thickness+2,length,22]);
    }
}

module motor_screws(sl=10) {
    rotate([0,0,45]) {
    translate([Motor_Bolt_X_spacing/2,0,0]) cylinder(sl,Screw_Size/2,Screw_Size/2,true);
    translate([-Motor_Bolt_X_spacing/2,0,0]) cylinder(sl,Screw_Size/2,Screw_Size/2,true);
    translate([0,Motor_Bolt_Y_spacing/2,0]) cylinder(sl,Screw_Size/2,Screw_Size/2,true);
    translate([0/2,-Motor_Bolt_Y_spacing/2,0]) cylinder(sl,Screw_Size/2,Screw_Size/2,true);
    }
}


module hw_qc_mount_extension() {
    difference() {
        union() {
            hw_qc_mini_mount(1);
            translate([18.75,30,-18.15]) cube([14.2,12,29.75]);
        }
        cube ([60,60,40]);
    }    
}


module hw_qc_mini_mount(scale) {polyhedron(
 points=[[40.293060302734375,22.34259796142578,3.034398078918457],[42.375370025634766,24.310165405273438,3.034398078918457],[40.31414794921875,22.320280075073242,2.732450485229492],[40.31414794921875,22.320280075073242,2.732450485229492],[42.375370025634766,24.310165405273438,3.034398078918457],[42.39645767211914,24.2878475189209,2.732450246810913],[40.31414794921875,22.320280075073242,2.732450485229492],[42.39645767211914,24.2878475189209,2.732450246810913],[42.375370025634766,24.310165405273438,2.4305026531219482],[42.375370025634766,24.310165405273438,3.034398078918457],[40.293060302734375,22.34259796142578,3.034398078918457],[42.31296920776367,24.376205444335938,3.323984146118164],[42.31296920776367,24.376205444335938,3.323984146118164],[40.293060302734375,22.34259796142578,3.034398078918457],[40.23065948486328,22.40863800048828,3.323984146118164],[42.31296920776367,24.376205444335938,3.323984146118164],[40.23065948486328,22.40863800048828,3.323984146118164],[42.21180725097656,24.48326301574707,3.589352607727051],[42.21180725097656,24.48326301574707,3.589352607727051],[40.23065948486328,22.40863800048828,3.323984146118164],[40.12949752807617,22.515697479248047,3.589352607727051],[42.21180725097656,24.48326301574707,3.589352607727051],[40.12949752807617,22.515697479248047,3.589352607727051],[42.07603073120117,24.6269588470459,3.8196394443511963],[42.07603073120117,24.6269588470459,3.8196394443511963],[40.12949752807617,22.515697479248047,3.589352607727051],[39.99372482299805,22.659391403198242,3.8196394443511963],[42.07603073120117,24.6269588470459,3.8196394443511963],[39.99372482299805,22.659391403198242,3.8196394443511963],[41.911197662353516,24.80140495300293,4.0054168701171875],[41.911197662353516,24.80140495300293,4.0054168701171875],[39.99372482299805,22.659391403198242,3.8196394443511963],[39.828887939453125,22.833837509155273,4.0054168701171875],[41.911197662353516,24.80140495300293,4.0054168701171875],[39.828887939453125,22.833837509155273,4.0054168701171875],[41.72405242919922,24.999462127685547,4.139078617095947],[41.72405242919922,24.999462127685547,4.139078617095947],[39.828887939453125,22.833837509155273,4.0054168701171875],[39.64174270629883,23.03189468383789,4.139078617095947],[41.72405242919922,24.999462127685547,4.139078617095947],[39.64174270629883,23.03189468383789,4.139078617095947],[41.52226257324219,25.213022232055664,4.215152740478516],[41.52226257324219,25.213022232055664,4.215152740478516],[39.64174270629883,23.03189468383789,4.139078617095947],[39.4399528503418,23.245454788208008,4.215152740478516],[41.52226257324219,25.213022232055664,4.215152740478516],[39.4399528503418,23.245454788208008,4.215152740478516],[41.314083099365234,25.43334197998047,4.230525016784668],[41.314083099365234,25.43334197998047,4.230525016784668],[39.4399528503418,23.245454788208008,4.215152740478516],[39.231773376464844,23.465774536132812,4.230525016784668],[41.314083099365234,25.43334197998047,4.230525016784668],[39.231773376464844,23.465774536132812,4.230525016784668],[41.10803985595703,25.651399612426758,4.184566020965576],[41.10803985595703,25.651399612426758,4.184566020965576],[39.231773376464844,23.465774536132812,4.230525016784668],[39.02573013305664,23.6838321685791,4.184566020965576],[41.10803985595703,25.651399612426758,4.184566020965576],[39.02573013305664,23.6838321685791,4.184566020965576],[40.912567138671875,25.8582706451416,4.07915735244751],[40.912567138671875,25.8582706451416,4.07915735244751],[39.02573013305664,23.6838321685791,4.184566020965576],[38.83026123046875,23.890703201293945,4.07915735244751],[40.912567138671875,25.8582706451416,4.07915735244751],[38.83026123046875,23.890703201293945,4.07915735244751],[40.73567199707031,26.045482635498047,3.918613910675049],[40.73567199707031,26.045482635498047,3.918613910675049],[38.83026123046875,23.890703201293945,4.07915735244751],[38.65336227416992,24.077917098999023,3.918613910675049],[40.73567199707031,26.045482635498047,3.918613910675049],[38.65336227416992,24.077917098999023,3.918613910675049],[40.584590911865234,26.205373764038086,3.7095091342926025],[40.584590911865234,26.205373764038086,3.7095091342926025],[38.65336227416992,24.077917098999023,3.918613910675049],[38.502281188964844,24.23780632019043,3.7095091342926025],[40.584590911865234,26.205373764038086,3.7095091342926025],[38.502281188964844,24.23780632019043,3.7095091342926025],[40.465511322021484,26.331398010253906,3.4604032039642334],[40.465511322021484,26.331398010253906,3.4604032039642334],[38.502281188964844,24.23780632019043,3.7095091342926025],[38.38320541381836,24.36383056640625,3.4604032039642334],[40.465511322021484,26.331398010253906,3.4604032039642334],[38.38320541381836,24.36383056640625,3.4604032039642334],[40.3833122253418,26.418394088745117,3.181494951248169],[40.3833122253418,26.418394088745117,3.181494951248169],[38.38320541381836,24.36383056640625,3.4604032039642334],[38.301002502441406,24.45082664489746,3.181494951248169],[40.3833122253418,26.418394088745117,3.181494951248169],[38.301002502441406,24.45082664489746,3.181494951248169],[40.34135055541992,26.462800979614258,2.8842029571533203],[40.34135055541992,26.462800979614258,2.8842029571533203],[38.301002502441406,24.45082664489746,3.181494951248169],[38.25904083251953,24.4952335357666,2.8842029571533203],[40.34135055541992,26.462800979614258,2.8842029571533203],[38.25904083251953,24.4952335357666,2.8842029571533203],[38.25904083251953,24.4952335357666,2.580697774887085],[40.34135055541992,26.462800979614258,2.8842029571533203],[38.25904083251953,24.4952335357666,2.580697774887085],[40.34135055541992,26.462800979614258,2.580697774887085],[40.34135055541992,26.462800979614258,2.580697774887085],[38.25904083251953,24.4952335357666,2.580697774887085],[38.301002502441406,24.45082664489746,2.2834057807922363],[40.34135055541992,26.462800979614258,2.580697774887085],[38.301002502441406,24.45082664489746,2.2834057807922363],[40.3833122253418,26.418394088745117,2.2834057807922363],[40.3833122253418,26.418394088745117,2.2834057807922363],[38.301002502441406,24.45082664489746,2.2834057807922363],[38.38320541381836,24.36383056640625,2.004497528076172],[40.3833122253418,26.418394088745117,2.2834057807922363],[38.38320541381836,24.36383056640625,2.004497528076172],[40.465511322021484,26.331398010253906,2.004497528076172],[40.465511322021484,26.331398010253906,2.004497528076172],[38.38320541381836,24.36383056640625,2.004497528076172],[38.502281188964844,24.23780632019043,1.7553915977478027],[40.465511322021484,26.331398010253906,2.004497528076172],[38.502281188964844,24.23780632019043,1.7553915977478027],[40.584590911865234,26.205373764038086,1.7553915977478027],[40.584590911865234,26.205373764038086,1.7553915977478027],[38.502281188964844,24.23780632019043,1.7553915977478027],[38.65336227416992,24.077917098999023,1.546286702156067],[40.584590911865234,26.205373764038086,1.7553915977478027],[38.65336227416992,24.077917098999023,1.546286702156067],[40.73567199707031,26.045482635498047,1.546286702156067],[40.73567199707031,26.045482635498047,1.546286702156067],[38.65336227416992,24.077917098999023,1.546286702156067],[38.83026123046875,23.890703201293945,1.385743498802185],[40.73567199707031,26.045482635498047,1.546286702156067],[38.83026123046875,23.890703201293945,1.385743498802185],[40.912567138671875,25.8582706451416,1.385743498802185],[40.912567138671875,25.8582706451416,1.385743498802185],[38.83026123046875,23.890703201293945,1.385743498802185],[39.02573013305664,23.6838321685791,1.280334711074829],[40.912567138671875,25.8582706451416,1.385743498802185],[39.02573013305664,23.6838321685791,1.280334711074829],[41.10803985595703,25.651399612426758,1.280334711074829],[41.10803985595703,25.651399612426758,1.280334711074829],[39.02573013305664,23.6838321685791,1.280334711074829],[39.231773376464844,23.465774536132812,1.2343755960464478],[41.10803985595703,25.651399612426758,1.280334711074829],[39.231773376464844,23.465774536132812,1.2343755960464478],[41.314083099365234,25.43334197998047,1.2343755960464478],[41.314083099365234,25.43334197998047,1.2343755960464478],[39.231773376464844,23.465774536132812,1.2343755960464478],[39.4399528503418,23.245454788208008,1.2497478723526],[41.314083099365234,25.43334197998047,1.2343755960464478],[39.4399528503418,23.245454788208008,1.2497478723526],[41.52226257324219,25.213022232055664,1.2497478723526],[41.52226257324219,25.213022232055664,1.2497478723526],[39.4399528503418,23.245454788208008,1.2497478723526],[39.64174270629883,23.03189468383789,1.325822114944458],[41.52226257324219,25.213022232055664,1.2497478723526],[39.64174270629883,23.03189468383789,1.325822114944458],[41.72405242919922,24.999462127685547,1.325822114944458],[41.72405242919922,24.999462127685547,1.325822114944458],[39.64174270629883,23.03189468383789,1.325822114944458],[39.828887939453125,22.833837509155273,1.4594839811325073],[41.72405242919922,24.999462127685547,1.325822114944458],[39.828887939453125,22.833837509155273,1.4594839811325073],[41.911197662353516,24.80140495300293,1.4594839811325073],[41.911197662353516,24.80140495300293,1.4594839811325073],[39.828887939453125,22.833837509155273,1.4594839811325073],[39.99372482299805,22.659391403198242,1.6452611684799194],[41.911197662353516,24.80140495300293,1.4594839811325073],[39.99372482299805,22.659391403198242,1.6452611684799194],[42.07603073120117,24.6269588470459,1.6452611684799194],[42.07603073120117,24.6269588470459,1.6452611684799194],[39.99372482299805,22.659391403198242,1.6452611684799194],[40.12949752807617,22.515697479248047,1.875548005104065],[42.07603073120117,24.6269588470459,1.6452611684799194],[40.12949752807617,22.515697479248047,1.875548005104065],[42.21180725097656,24.48326301574707,1.875548005104065],[42.21180725097656,24.48326301574707,1.875548005104065],[40.12949752807617,22.515697479248047,1.875548005104065],[40.23065948486328,22.40863800048828,2.140916585922241],[42.21180725097656,24.48326301574707,1.875548005104065],[40.23065948486328,22.40863800048828,2.140916585922241],[42.31296920776367,24.376205444335938,2.140916585922241],[42.31296920776367,24.376205444335938,2.140916585922241],[40.23065948486328,22.40863800048828,2.140916585922241],[40.293060302734375,22.34259796142578,2.4305026531219482],[42.31296920776367,24.376205444335938,2.140916585922241],[40.293060302734375,22.34259796142578,2.4305026531219482],[42.375370025634766,24.310165405273438,2.4305026531219482],[42.375370025634766,24.310165405273438,2.4305026531219482],[40.293060302734375,22.34259796142578,2.4305026531219482],[40.31414794921875,22.320280075073242,2.732450485229492],[32.91769790649414,32.08687973022461,-18.16754913330078],[18.725351333618164,32.08687973022461,-18.16754913330078],[32.91769790649414,32.08687973022461,11.432450294494629],[32.91769790649414,32.08687973022461,11.432450294494629],[18.725351333618164,32.08687973022461,-18.16754913330078],[18.725351333618164,32.08687973022461,11.432450294494629],[15.360396385192871,26.586877822875977,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[15.360396385192871,26.586877822875977,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[36.28265380859375,26.586877822875977,-18.16754913330078],[36.28265380859375,26.586877822875977,11.432450294494629],[43.92515563964844,18.498689651489258,-18.16754913330078],[39.64174270629883,23.03189468383789,1.325822114944458],[36.28265380859375,26.586877822875977,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[39.64174270629883,23.03189468383789,1.325822114944458],[39.4399528503418,23.245454788208008,1.2497478723526],[36.28265380859375,26.586877822875977,-18.16754913330078],[39.4399528503418,23.245454788208008,1.2497478723526],[39.231773376464844,23.465774536132812,1.2343755960464478],[43.92515563964844,18.498689651489258,11.432450294494629],[40.293060302734375,22.34259796142578,2.4305026531219482],[43.92515563964844,18.498689651489258,-18.16754913330078],[43.92515563964844,18.498689651489258,-18.16754913330078],[40.293060302734375,22.34259796142578,2.4305026531219482],[40.23065948486328,22.40863800048828,2.140916585922241],[43.92515563964844,18.498689651489258,-18.16754913330078],[40.23065948486328,22.40863800048828,2.140916585922241],[40.12949752807617,22.515697479248047,1.875548005104065],[36.28265380859375,26.586877822875977,11.432450294494629],[39.64174270629883,23.03189468383789,4.139078617095947],[43.92515563964844,18.498689651489258,11.432450294494629],[43.92515563964844,18.498689651489258,11.432450294494629],[39.64174270629883,23.03189468383789,4.139078617095947],[39.828887939453125,22.833837509155273,4.0054168701171875],[43.92515563964844,18.498689651489258,11.432450294494629],[39.828887939453125,22.833837509155273,4.0054168701171875],[39.99372482299805,22.659391403198242,3.8196394443511963],[36.28265380859375,26.586877822875977,-18.16754913330078],[38.25904083251953,24.4952335357666,2.580697774887085],[36.28265380859375,26.586877822875977,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[38.25904083251953,24.4952335357666,2.580697774887085],[38.25904083251953,24.4952335357666,2.8842029571533203],[36.28265380859375,26.586877822875977,11.432450294494629],[38.25904083251953,24.4952335357666,2.8842029571533203],[38.301002502441406,24.45082664489746,3.181494951248169],[40.293060302734375,22.34259796142578,3.034398078918457],[40.31414794921875,22.320280075073242,2.732450485229492],[43.92515563964844,18.498689651489258,11.432450294494629],[43.92515563964844,18.498689651489258,11.432450294494629],[40.31414794921875,22.320280075073242,2.732450485229492],[40.293060302734375,22.34259796142578,2.4305026531219482],[40.12949752807617,22.515697479248047,1.875548005104065],[39.99372482299805,22.659391403198242,1.6452611684799194],[43.92515563964844,18.498689651489258,-18.16754913330078],[43.92515563964844,18.498689651489258,-18.16754913330078],[39.99372482299805,22.659391403198242,1.6452611684799194],[39.828887939453125,22.833837509155273,1.4594839811325073],[43.92515563964844,18.498689651489258,-18.16754913330078],[39.828887939453125,22.833837509155273,1.4594839811325073],[39.64174270629883,23.03189468383789,1.325822114944458],[39.231773376464844,23.465774536132812,1.2343755960464478],[39.02573013305664,23.6838321685791,1.280334711074829],[36.28265380859375,26.586877822875977,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[39.02573013305664,23.6838321685791,1.280334711074829],[38.83026123046875,23.890703201293945,1.385743498802185],[36.28265380859375,26.586877822875977,-18.16754913330078],[38.83026123046875,23.890703201293945,1.385743498802185],[38.65336227416992,24.077917098999023,1.546286702156067],[38.65336227416992,24.077917098999023,1.546286702156067],[38.502281188964844,24.23780632019043,1.7553915977478027],[36.28265380859375,26.586877822875977,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[38.502281188964844,24.23780632019043,1.7553915977478027],[38.38320541381836,24.36383056640625,2.004497528076172],[36.28265380859375,26.586877822875977,-18.16754913330078],[38.38320541381836,24.36383056640625,2.004497528076172],[38.301002502441406,24.45082664489746,2.2834057807922363],[38.301002502441406,24.45082664489746,2.2834057807922363],[38.25904083251953,24.4952335357666,2.580697774887085],[36.28265380859375,26.586877822875977,-18.16754913330078],[38.301002502441406,24.45082664489746,3.181494951248169],[38.38320541381836,24.36383056640625,3.4604032039642334],[36.28265380859375,26.586877822875977,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[38.38320541381836,24.36383056640625,3.4604032039642334],[38.502281188964844,24.23780632019043,3.7095091342926025],[36.28265380859375,26.586877822875977,11.432450294494629],[38.502281188964844,24.23780632019043,3.7095091342926025],[38.65336227416992,24.077917098999023,3.918613910675049],[38.65336227416992,24.077917098999023,3.918613910675049],[38.83026123046875,23.890703201293945,4.07915735244751],[36.28265380859375,26.586877822875977,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[38.83026123046875,23.890703201293945,4.07915735244751],[39.02573013305664,23.6838321685791,4.184566020965576],[36.28265380859375,26.586877822875977,11.432450294494629],[39.02573013305664,23.6838321685791,4.184566020965576],[39.231773376464844,23.465774536132812,4.230525016784668],[39.231773376464844,23.465774536132812,4.230525016784668],[39.4399528503418,23.245454788208008,4.215152740478516],[36.28265380859375,26.586877822875977,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[39.4399528503418,23.245454788208008,4.215152740478516],[39.64174270629883,23.03189468383789,4.139078617095947],[39.99372482299805,22.659391403198242,3.8196394443511963],[40.12949752807617,22.515697479248047,3.589352607727051],[43.92515563964844,18.498689651489258,11.432450294494629],[43.92515563964844,18.498689651489258,11.432450294494629],[40.12949752807617,22.515697479248047,3.589352607727051],[40.23065948486328,22.40863800048828,3.323984146118164],[43.92515563964844,18.498689651489258,11.432450294494629],[40.23065948486328,22.40863800048828,3.323984146118164],[40.293060302734375,22.34259796142578,3.034398078918457],[45.864749908447266,20.617294311523438,-18.16754913330078],[42.375370025634766,24.310165405273438,2.4305026531219482],[45.864749908447266,20.617294311523438,11.432450294494629],[45.864749908447266,20.617294311523438,11.432450294494629],[42.375370025634766,24.310165405273438,2.4305026531219482],[42.39645767211914,24.2878475189209,2.732450246810913],[45.864749908447266,20.617294311523438,11.432450294494629],[42.39645767211914,24.2878475189209,2.732450246810913],[42.375370025634766,24.310165405273438,3.034398078918457],[38.14533615112305,28.78687858581543,-18.16754913330078],[41.52226257324219,25.213022232055664,1.2497478723526],[45.864749908447266,20.617294311523438,-18.16754913330078],[45.864749908447266,20.617294311523438,-18.16754913330078],[41.52226257324219,25.213022232055664,1.2497478723526],[41.72405242919922,24.999462127685547,1.325822114944458],[45.864749908447266,20.617294311523438,-18.16754913330078],[41.72405242919922,24.999462127685547,1.325822114944458],[41.911197662353516,24.80140495300293,1.4594839811325073],[38.14533615112305,28.78687858581543,11.432450294494629],[40.34135055541992,26.462800979614258,2.580697774887085],[38.14533615112305,28.78687858581543,-18.16754913330078],[38.14533615112305,28.78687858581543,-18.16754913330078],[40.34135055541992,26.462800979614258,2.580697774887085],[40.3833122253418,26.418394088745117,2.2834057807922363],[38.14533615112305,28.78687858581543,-18.16754913330078],[40.3833122253418,26.418394088745117,2.2834057807922363],[40.465511322021484,26.331398010253906,2.004497528076172],[45.864749908447266,20.617294311523438,11.432450294494629],[41.52226257324219,25.213022232055664,4.215152740478516],[38.14533615112305,28.78687858581543,11.432450294494629],[38.14533615112305,28.78687858581543,11.432450294494629],[41.52226257324219,25.213022232055664,4.215152740478516],[41.314083099365234,25.43334197998047,4.230525016784668],[38.14533615112305,28.78687858581543,11.432450294494629],[41.314083099365234,25.43334197998047,4.230525016784668],[41.10803985595703,25.651399612426758,4.184566020965576],[42.375370025634766,24.310165405273438,3.034398078918457],[42.31296920776367,24.376205444335938,3.323984146118164],[45.864749908447266,20.617294311523438,11.432450294494629],[45.864749908447266,20.617294311523438,11.432450294494629],[42.31296920776367,24.376205444335938,3.323984146118164],[42.21180725097656,24.48326301574707,3.589352607727051],[45.864749908447266,20.617294311523438,11.432450294494629],[42.21180725097656,24.48326301574707,3.589352607727051],[42.07603073120117,24.6269588470459,3.8196394443511963],[42.07603073120117,24.6269588470459,3.8196394443511963],[41.911197662353516,24.80140495300293,4.0054168701171875],[45.864749908447266,20.617294311523438,11.432450294494629],[45.864749908447266,20.617294311523438,11.432450294494629],[41.911197662353516,24.80140495300293,4.0054168701171875],[41.72405242919922,24.999462127685547,4.139078617095947],[45.864749908447266,20.617294311523438,11.432450294494629],[41.72405242919922,24.999462127685547,4.139078617095947],[41.52226257324219,25.213022232055664,4.215152740478516],[41.10803985595703,25.651399612426758,4.184566020965576],[40.912567138671875,25.8582706451416,4.07915735244751],[38.14533615112305,28.78687858581543,11.432450294494629],[38.14533615112305,28.78687858581543,11.432450294494629],[40.912567138671875,25.8582706451416,4.07915735244751],[40.73567199707031,26.045482635498047,3.918613910675049],[38.14533615112305,28.78687858581543,11.432450294494629],[40.73567199707031,26.045482635498047,3.918613910675049],[40.584590911865234,26.205373764038086,3.7095091342926025],[40.584590911865234,26.205373764038086,3.7095091342926025],[40.465511322021484,26.331398010253906,3.4604032039642334],[38.14533615112305,28.78687858581543,11.432450294494629],[38.14533615112305,28.78687858581543,11.432450294494629],[40.465511322021484,26.331398010253906,3.4604032039642334],[40.3833122253418,26.418394088745117,3.181494951248169],[38.14533615112305,28.78687858581543,11.432450294494629],[40.3833122253418,26.418394088745117,3.181494951248169],[40.34135055541992,26.462800979614258,2.8842029571533203],[40.34135055541992,26.462800979614258,2.8842029571533203],[40.34135055541992,26.462800979614258,2.580697774887085],[38.14533615112305,28.78687858581543,11.432450294494629],[40.465511322021484,26.331398010253906,2.004497528076172],[40.584590911865234,26.205373764038086,1.7553915977478027],[38.14533615112305,28.78687858581543,-18.16754913330078],[38.14533615112305,28.78687858581543,-18.16754913330078],[40.584590911865234,26.205373764038086,1.7553915977478027],[40.73567199707031,26.045482635498047,1.546286702156067],[38.14533615112305,28.78687858581543,-18.16754913330078],[40.73567199707031,26.045482635498047,1.546286702156067],[40.912567138671875,25.8582706451416,1.385743498802185],[40.912567138671875,25.8582706451416,1.385743498802185],[41.10803985595703,25.651399612426758,1.280334711074829],[38.14533615112305,28.78687858581543,-18.16754913330078],[38.14533615112305,28.78687858581543,-18.16754913330078],[41.10803985595703,25.651399612426758,1.280334711074829],[41.314083099365234,25.43334197998047,1.2343755960464478],[38.14533615112305,28.78687858581543,-18.16754913330078],[41.314083099365234,25.43334197998047,1.2343755960464478],[41.52226257324219,25.213022232055664,1.2497478723526],[41.911197662353516,24.80140495300293,1.4594839811325073],[42.07603073120117,24.6269588470459,1.6452611684799194],[45.864749908447266,20.617294311523438,-18.16754913330078],[45.864749908447266,20.617294311523438,-18.16754913330078],[42.07603073120117,24.6269588470459,1.6452611684799194],[42.21180725097656,24.48326301574707,1.875548005104065],[45.864749908447266,20.617294311523438,-18.16754913330078],[42.21180725097656,24.48326301574707,1.875548005104065],[42.31296920776367,24.376205444335938,2.140916585922241],[42.31296920776367,24.376205444335938,2.140916585922241],[42.375370025634766,24.310165405273438,2.4305026531219482],[45.864749908447266,20.617294311523438,-18.16754913330078],[32.91769790649414,28.78687858581543,-18.16754913330078],[32.91769790649414,32.08687973022461,-18.16754913330078],[32.91769790649414,28.78687858581543,11.432450294494629],[32.91769790649414,28.78687858581543,11.432450294494629],[32.91769790649414,32.08687973022461,-18.16754913330078],[32.91769790649414,32.08687973022461,11.432450294494629],[5.7783002853393555,20.61729621887207,-18.16754913330078],[7.717895030975342,18.49869155883789,-18.16754913330078],[5.7783002853393555,20.61729621887207,11.432450294494629],[5.7783002853393555,20.61729621887207,11.432450294494629],[7.717895030975342,18.49869155883789,-18.16754913330078],[7.717895030975342,18.49869155883789,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[13.368205070495605,24.47850799560547,2.4305026531219482],[15.360396385192871,26.586877822875977,-18.16754913330078],[15.360396385192871,26.586877822875977,-18.16754913330078],[13.368205070495605,24.47850799560547,2.4305026531219482],[13.305804252624512,24.41246795654297,2.140916585922241],[15.360396385192871,26.586877822875977,-18.16754913330078],[13.305804252624512,24.41246795654297,2.140916585922241],[13.204645156860352,24.305410385131836,1.875548005104065],[7.717895030975342,18.49869155883789,11.432450294494629],[12.100876808166504,23.13727378845215,4.184566020965576],[15.360396385192871,26.586877822875977,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[12.100876808166504,23.13727378845215,4.184566020965576],[12.30691909790039,23.355331420898438,4.230525016784668],[15.360396385192871,26.586877822875977,11.432450294494629],[12.30691909790039,23.355331420898438,4.230525016784668],[12.515097618103027,23.575651168823242,4.215152740478516],[7.717895030975342,18.49869155883789,-18.16754913330078],[11.334187507629395,22.32587432861328,2.580697774887085],[7.717895030975342,18.49869155883789,11.432450294494629],[7.717895030975342,18.49869155883789,11.432450294494629],[11.334187507629395,22.32587432861328,2.580697774887085],[11.334187507629395,22.32587432861328,2.8842029571533203],[7.717895030975342,18.49869155883789,11.432450294494629],[11.334187507629395,22.32587432861328,2.8842029571533203],[11.376147270202637,22.370281219482422,3.181494951248169],[15.360396385192871,26.586877822875977,-18.16754913330078],[12.100876808166504,23.13727378845215,1.280334711074829],[7.717895030975342,18.49869155883789,-18.16754913330078],[7.717895030975342,18.49869155883789,-18.16754913330078],[12.100876808166504,23.13727378845215,1.280334711074829],[11.905405044555664,22.930402755737305,1.385743498802185],[7.717895030975342,18.49869155883789,-18.16754913330078],[11.905405044555664,22.930402755737305,1.385743498802185],[11.728508949279785,22.74319076538086,1.546286702156067],[13.368205070495605,24.47850799560547,3.034398078918457],[13.389293670654297,24.500825881958008,2.732450485229492],[15.360396385192871,26.586877822875977,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[13.389293670654297,24.500825881958008,2.732450485229492],[13.368205070495605,24.47850799560547,2.4305026531219482],[13.204645156860352,24.305410385131836,1.875548005104065],[13.068868637084961,24.16171646118164,1.6452611684799194],[15.360396385192871,26.586877822875977,-18.16754913330078],[15.360396385192871,26.586877822875977,-18.16754913330078],[13.068868637084961,24.16171646118164,1.6452611684799194],[12.904034614562988,23.987268447875977,1.4594839811325073],[15.360396385192871,26.586877822875977,-18.16754913330078],[12.904034614562988,23.987268447875977,1.4594839811325073],[12.716890335083008,23.78921127319336,1.325822114944458],[12.716890335083008,23.78921127319336,1.325822114944458],[12.515097618103027,23.575651168823242,1.2497478723526],[15.360396385192871,26.586877822875977,-18.16754913330078],[15.360396385192871,26.586877822875977,-18.16754913330078],[12.515097618103027,23.575651168823242,1.2497478723526],[12.30691909790039,23.355331420898438,1.2343755960464478],[15.360396385192871,26.586877822875977,-18.16754913330078],[12.30691909790039,23.355331420898438,1.2343755960464478],[12.100876808166504,23.13727378845215,1.280334711074829],[11.728508949279785,22.74319076538086,1.546286702156067],[11.577427864074707,22.58329963684082,1.7553915977478027],[7.717895030975342,18.49869155883789,-18.16754913330078],[7.717895030975342,18.49869155883789,-18.16754913330078],[11.577427864074707,22.58329963684082,1.7553915977478027],[11.458349227905273,22.457275390625,2.004497528076172],[7.717895030975342,18.49869155883789,-18.16754913330078],[11.458349227905273,22.457275390625,2.004497528076172],[11.376147270202637,22.370281219482422,2.2834057807922363],[11.376147270202637,22.370281219482422,2.2834057807922363],[11.334187507629395,22.32587432861328,2.580697774887085],[7.717895030975342,18.49869155883789,-18.16754913330078],[11.376147270202637,22.370281219482422,3.181494951248169],[11.458349227905273,22.457275390625,3.4604032039642334],[7.717895030975342,18.49869155883789,11.432450294494629],[7.717895030975342,18.49869155883789,11.432450294494629],[11.458349227905273,22.457275390625,3.4604032039642334],[11.577427864074707,22.58329963684082,3.7095091342926025],[7.717895030975342,18.49869155883789,11.432450294494629],[11.577427864074707,22.58329963684082,3.7095091342926025],[11.728508949279785,22.74319076538086,3.918613910675049],[11.728508949279785,22.74319076538086,3.918613910675049],[11.905405044555664,22.930402755737305,4.07915735244751],[7.717895030975342,18.49869155883789,11.432450294494629],[7.717895030975342,18.49869155883789,11.432450294494629],[11.905405044555664,22.930402755737305,4.07915735244751],[12.100876808166504,23.13727378845215,4.184566020965576],[12.515097618103027,23.575651168823242,4.215152740478516],[12.716890335083008,23.78921127319336,4.139078617095947],[15.360396385192871,26.586877822875977,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[12.716890335083008,23.78921127319336,4.139078617095947],[12.904034614562988,23.987268447875977,4.0054168701171875],[15.360396385192871,26.586877822875977,11.432450294494629],[12.904034614562988,23.987268447875977,4.0054168701171875],[13.068868637084961,24.16171646118164,3.8196394443511963],[13.068868637084961,24.16171646118164,3.8196394443511963],[13.204645156860352,24.305410385131836,3.589352607727051],[15.360396385192871,26.586877822875977,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[13.204645156860352,24.305410385131836,3.589352607727051],[13.305804252624512,24.41246795654297,3.323984146118164],[15.360396385192871,26.586877822875977,11.432450294494629],[13.305804252624512,24.41246795654297,3.323984146118164],[13.368205070495605,24.47850799560547,3.034398078918457],[43.92515563964844,18.498689651489258,-18.16754913330078],[45.864749908447266,20.617294311523438,-18.16754913330078],[43.92515563964844,18.498689651489258,11.432450294494629],[43.92515563964844,18.498689651489258,11.432450294494629],[45.864749908447266,20.617294311523438,-18.16754913330078],[45.864749908447266,20.617294311523438,11.432450294494629],[38.14533615112305,28.78687858581543,-18.16754913330078],[32.91769790649414,28.78687858581543,-18.16754913330078],[38.14533615112305,28.78687858581543,11.432450294494629],[38.14533615112305,28.78687858581543,11.432450294494629],[32.91769790649414,28.78687858581543,-18.16754913330078],[32.91769790649414,28.78687858581543,11.432450294494629],[13.368205070495605,24.47850799560547,2.4305026531219482],[13.389293670654297,24.500825881958008,2.732450485229492],[11.306984901428223,26.468393325805664,2.732450485229492],[11.306984901428223,26.468393325805664,2.732450485229492],[13.389293670654297,24.500825881958008,2.732450485229492],[13.368205070495605,24.47850799560547,3.034398078918457],[11.306984901428223,26.468393325805664,2.732450485229492],[13.368205070495605,24.47850799560547,3.034398078918457],[11.285896301269531,26.446075439453125,3.034398078918457],[11.285896301269531,26.446075439453125,3.034398078918457],[13.368205070495605,24.47850799560547,3.034398078918457],[13.305804252624512,24.41246795654297,3.323984146118164],[11.285896301269531,26.446075439453125,3.034398078918457],[13.305804252624512,24.41246795654297,3.323984146118164],[11.223495483398438,26.380035400390625,3.323984146118164],[11.223495483398438,26.380035400390625,3.323984146118164],[13.305804252624512,24.41246795654297,3.323984146118164],[13.204645156860352,24.305410385131836,3.589352607727051],[11.223495483398438,26.380035400390625,3.323984146118164],[13.204645156860352,24.305410385131836,3.589352607727051],[11.122335433959961,26.272977828979492,3.589352607727051],[11.122335433959961,26.272977828979492,3.589352607727051],[13.204645156860352,24.305410385131836,3.589352607727051],[13.068868637084961,24.16171646118164,3.8196394443511963],[11.122335433959961,26.272977828979492,3.589352607727051],[13.068868637084961,24.16171646118164,3.8196394443511963],[10.986559867858887,26.129281997680664,3.8196394443511963],[10.986559867858887,26.129281997680664,3.8196394443511963],[13.068868637084961,24.16171646118164,3.8196394443511963],[12.904034614562988,23.987268447875977,4.0054168701171875],[10.986559867858887,26.129281997680664,3.8196394443511963],[12.904034614562988,23.987268447875977,4.0054168701171875],[10.821724891662598,25.954835891723633,4.0054168701171875],[10.821724891662598,25.954835891723633,4.0054168701171875],[12.904034614562988,23.987268447875977,4.0054168701171875],[12.716890335083008,23.78921127319336,4.139078617095947],[10.821724891662598,25.954835891723633,4.0054168701171875],[12.716890335083008,23.78921127319336,4.139078617095947],[10.634581565856934,25.756778717041016,4.139078617095947],[10.634581565856934,25.756778717041016,4.139078617095947],[12.716890335083008,23.78921127319336,4.139078617095947],[12.515097618103027,23.575651168823242,4.215152740478516],[10.634581565856934,25.756778717041016,4.139078617095947],[12.515097618103027,23.575651168823242,4.215152740478516],[10.432788848876953,25.5432186126709,4.215152740478516],[10.432788848876953,25.5432186126709,4.215152740478516],[12.515097618103027,23.575651168823242,4.215152740478516],[12.30691909790039,23.355331420898438,4.230525016784668],[10.432788848876953,25.5432186126709,4.215152740478516],[12.30691909790039,23.355331420898438,4.230525016784668],[10.224610328674316,25.322898864746094,4.230525016784668],[10.224610328674316,25.322898864746094,4.230525016784668],[12.30691909790039,23.355331420898438,4.230525016784668],[12.100876808166504,23.13727378845215,4.184566020965576],[10.224610328674316,25.322898864746094,4.230525016784668],[12.100876808166504,23.13727378845215,4.184566020965576],[10.018567085266113,25.104841232299805,4.184566020965576],[10.018567085266113,25.104841232299805,4.184566020965576],[12.100876808166504,23.13727378845215,4.184566020965576],[11.905405044555664,22.930402755737305,4.07915735244751],[10.018567085266113,25.104841232299805,4.184566020965576],[11.905405044555664,22.930402755737305,4.07915735244751],[9.82309627532959,24.89797019958496,4.07915735244751],[9.82309627532959,24.89797019958496,4.07915735244751],[11.905405044555664,22.930402755737305,4.07915735244751],[11.728508949279785,22.74319076538086,3.918613910675049],[9.82309627532959,24.89797019958496,4.07915735244751],[11.728508949279785,22.74319076538086,3.918613910675049],[9.646199226379395,24.710758209228516,3.918613910675049],[9.646199226379395,24.710758209228516,3.918613910675049],[11.728508949279785,22.74319076538086,3.918613910675049],[11.577427864074707,22.58329963684082,3.7095091342926025],[9.646199226379395,24.710758209228516,3.918613910675049],[11.577427864074707,22.58329963684082,3.7095091342926025],[9.495119094848633,24.550867080688477,3.7095091342926025],[9.495119094848633,24.550867080688477,3.7095091342926025],[11.577427864074707,22.58329963684082,3.7095091342926025],[11.458349227905273,22.457275390625,3.4604032039642334],[9.495119094848633,24.550867080688477,3.7095091342926025],[11.458349227905273,22.457275390625,3.4604032039642334],[9.3760404586792,24.424842834472656,3.4604032039642334],[9.3760404586792,24.424842834472656,3.4604032039642334],[11.458349227905273,22.457275390625,3.4604032039642334],[11.376147270202637,22.370281219482422,3.181494951248169],[9.3760404586792,24.424842834472656,3.4604032039642334],[11.376147270202637,22.370281219482422,3.181494951248169],[9.293838500976562,24.337846755981445,3.181494951248169],[9.293838500976562,24.337846755981445,3.181494951248169],[11.376147270202637,22.370281219482422,3.181494951248169],[11.334187507629395,22.32587432861328,2.8842029571533203],[9.293838500976562,24.337846755981445,3.181494951248169],[11.334187507629395,22.32587432861328,2.8842029571533203],[9.25187873840332,24.293439865112305,2.8842029571533203],[9.25187873840332,24.293439865112305,2.8842029571533203],[11.334187507629395,22.32587432861328,2.8842029571533203],[11.334187507629395,22.32587432861328,2.580697774887085],[9.25187873840332,24.293439865112305,2.8842029571533203],[11.334187507629395,22.32587432861328,2.580697774887085],[9.25187873840332,24.293439865112305,2.580697774887085],[9.25187873840332,24.293439865112305,2.580697774887085],[11.334187507629395,22.32587432861328,2.580697774887085],[11.376147270202637,22.370281219482422,2.2834057807922363],[9.25187873840332,24.293439865112305,2.580697774887085],[11.376147270202637,22.370281219482422,2.2834057807922363],[9.293838500976562,24.337846755981445,2.2834057807922363],[9.293838500976562,24.337846755981445,2.2834057807922363],[11.376147270202637,22.370281219482422,2.2834057807922363],[9.3760404586792,24.424842834472656,2.004497528076172],[9.3760404586792,24.424842834472656,2.004497528076172],[11.376147270202637,22.370281219482422,2.2834057807922363],[11.458349227905273,22.457275390625,2.004497528076172],[9.3760404586792,24.424842834472656,2.004497528076172],[11.458349227905273,22.457275390625,2.004497528076172],[9.495119094848633,24.550867080688477,1.7553915977478027],[9.495119094848633,24.550867080688477,1.7553915977478027],[11.458349227905273,22.457275390625,2.004497528076172],[11.577427864074707,22.58329963684082,1.7553915977478027],[9.495119094848633,24.550867080688477,1.7553915977478027],[11.577427864074707,22.58329963684082,1.7553915977478027],[9.646199226379395,24.710758209228516,1.546286702156067],[9.646199226379395,24.710758209228516,1.546286702156067],[11.577427864074707,22.58329963684082,1.7553915977478027],[11.728508949279785,22.74319076538086,1.546286702156067],[9.646199226379395,24.710758209228516,1.546286702156067],[11.728508949279785,22.74319076538086,1.546286702156067],[9.82309627532959,24.89797019958496,1.385743498802185],[9.82309627532959,24.89797019958496,1.385743498802185],[11.728508949279785,22.74319076538086,1.546286702156067],[11.905405044555664,22.930402755737305,1.385743498802185],[9.82309627532959,24.89797019958496,1.385743498802185],[11.905405044555664,22.930402755737305,1.385743498802185],[10.018567085266113,25.104841232299805,1.280334711074829],[10.018567085266113,25.104841232299805,1.280334711074829],[11.905405044555664,22.930402755737305,1.385743498802185],[12.100876808166504,23.13727378845215,1.280334711074829],[10.018567085266113,25.104841232299805,1.280334711074829],[12.100876808166504,23.13727378845215,1.280334711074829],[10.224610328674316,25.322898864746094,1.2343755960464478],[10.224610328674316,25.322898864746094,1.2343755960464478],[12.100876808166504,23.13727378845215,1.280334711074829],[12.30691909790039,23.355331420898438,1.2343755960464478],[10.224610328674316,25.322898864746094,1.2343755960464478],[12.30691909790039,23.355331420898438,1.2343755960464478],[10.432788848876953,25.5432186126709,1.2497478723526],[10.432788848876953,25.5432186126709,1.2497478723526],[12.30691909790039,23.355331420898438,1.2343755960464478],[12.515097618103027,23.575651168823242,1.2497478723526],[10.432788848876953,25.5432186126709,1.2497478723526],[12.515097618103027,23.575651168823242,1.2497478723526],[10.634581565856934,25.756778717041016,1.325822114944458],[10.634581565856934,25.756778717041016,1.325822114944458],[12.515097618103027,23.575651168823242,1.2497478723526],[12.716890335083008,23.78921127319336,1.325822114944458],[10.634581565856934,25.756778717041016,1.325822114944458],[12.716890335083008,23.78921127319336,1.325822114944458],[10.821724891662598,25.954835891723633,1.4594839811325073],[10.821724891662598,25.954835891723633,1.4594839811325073],[12.716890335083008,23.78921127319336,1.325822114944458],[12.904034614562988,23.987268447875977,1.4594839811325073],[10.821724891662598,25.954835891723633,1.4594839811325073],[12.904034614562988,23.987268447875977,1.4594839811325073],[10.986559867858887,26.129281997680664,1.6452611684799194],[10.986559867858887,26.129281997680664,1.6452611684799194],[12.904034614562988,23.987268447875977,1.4594839811325073],[13.068868637084961,24.16171646118164,1.6452611684799194],[10.986559867858887,26.129281997680664,1.6452611684799194],[13.068868637084961,24.16171646118164,1.6452611684799194],[11.122335433959961,26.272977828979492,1.875548005104065],[11.122335433959961,26.272977828979492,1.875548005104065],[13.068868637084961,24.16171646118164,1.6452611684799194],[13.204645156860352,24.305410385131836,1.875548005104065],[11.122335433959961,26.272977828979492,1.875548005104065],[13.204645156860352,24.305410385131836,1.875548005104065],[11.223495483398438,26.380035400390625,2.140916585922241],[11.223495483398438,26.380035400390625,2.140916585922241],[13.204645156860352,24.305410385131836,1.875548005104065],[13.305804252624512,24.41246795654297,2.140916585922241],[11.223495483398438,26.380035400390625,2.140916585922241],[13.305804252624512,24.41246795654297,2.140916585922241],[11.285896301269531,26.446075439453125,2.4305026531219482],[11.285896301269531,26.446075439453125,2.4305026531219482],[13.305804252624512,24.41246795654297,2.140916585922241],[13.368205070495605,24.47850799560547,2.4305026531219482],[11.285896301269531,26.446075439453125,2.4305026531219482],[13.368205070495605,24.47850799560547,2.4305026531219482],[11.306984901428223,26.468393325805664,2.732450485229492],[43.92515563964844,18.498689651489258,11.432450294494629],[45.864749908447266,20.617294311523438,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[45.864749908447266,20.617294311523438,11.432450294494629],[38.14533615112305,28.78687858581543,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[38.14533615112305,28.78687858581543,11.432450294494629],[32.91769790649414,28.78687858581543,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[32.91769790649414,28.78687858581543,11.432450294494629],[18.725351333618164,28.78687858581543,11.432450294494629],[18.725351333618164,28.78687858581543,11.432450294494629],[32.91769790649414,28.78687858581543,11.432450294494629],[32.91769790649414,32.08687973022461,11.432450294494629],[18.725351333618164,28.78687858581543,11.432450294494629],[32.91769790649414,32.08687973022461,11.432450294494629],[18.725351333618164,32.08687973022461,11.432450294494629],[36.28265380859375,26.586877822875977,11.432450294494629],[18.725351333618164,28.78687858581543,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[18.725351333618164,28.78687858581543,11.432450294494629],[13.497713088989258,28.78687858581543,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[13.497713088989258,28.78687858581543,11.432450294494629],[5.7783002853393555,20.61729621887207,11.432450294494629],[5.7783002853393555,20.61729621887207,11.432450294494629],[7.717895030975342,18.49869155883789,11.432450294494629],[15.360396385192871,26.586877822875977,11.432450294494629],[7.717895030975342,18.49869155883789,-18.16754913330078],[5.7783002853393555,20.61729621887207,-18.16754913330078],[15.360396385192871,26.586877822875977,-18.16754913330078],[15.360396385192871,26.586877822875977,-18.16754913330078],[5.7783002853393555,20.61729621887207,-18.16754913330078],[13.497713088989258,28.78687858581543,-18.16754913330078],[15.360396385192871,26.586877822875977,-18.16754913330078],[13.497713088989258,28.78687858581543,-18.16754913330078],[18.725351333618164,28.78687858581543,-18.16754913330078],[18.725351333618164,32.08687973022461,-18.16754913330078],[32.91769790649414,28.78687858581543,-18.16754913330078],[18.725351333618164,28.78687858581543,-18.16754913330078],[18.725351333618164,28.78687858581543,-18.16754913330078],[32.91769790649414,28.78687858581543,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[18.725351333618164,28.78687858581543,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[15.360396385192871,26.586877822875977,-18.16754913330078],[18.725351333618164,32.08687973022461,-18.16754913330078],[32.91769790649414,32.08687973022461,-18.16754913330078],[32.91769790649414,28.78687858581543,-18.16754913330078],[32.91769790649414,28.78687858581543,-18.16754913330078],[38.14533615112305,28.78687858581543,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[38.14533615112305,28.78687858581543,-18.16754913330078],[45.864749908447266,20.617294311523438,-18.16754913330078],[36.28265380859375,26.586877822875977,-18.16754913330078],[45.864749908447266,20.617294311523438,-18.16754913330078],[43.92515563964844,18.498689651489258,-18.16754913330078],[5.7783002853393555,20.61729621887207,-18.16754913330078],[10.018567085266113,25.104841232299805,1.280334711074829],[13.497713088989258,28.78687858581543,-18.16754913330078],[13.497713088989258,28.78687858581543,-18.16754913330078],[10.018567085266113,25.104841232299805,1.280334711074829],[10.224610328674316,25.322898864746094,1.2343755960464478],[13.497713088989258,28.78687858581543,-18.16754913330078],[10.224610328674316,25.322898864746094,1.2343755960464478],[10.432788848876953,25.5432186126709,1.2497478723526],[5.7783002853393555,20.61729621887207,11.432450294494629],[9.25187873840332,24.293439865112305,2.580697774887085],[5.7783002853393555,20.61729621887207,-18.16754913330078],[5.7783002853393555,20.61729621887207,-18.16754913330078],[9.25187873840332,24.293439865112305,2.580697774887085],[9.293838500976562,24.337846755981445,2.2834057807922363],[5.7783002853393555,20.61729621887207,-18.16754913330078],[9.293838500976562,24.337846755981445,2.2834057807922363],[9.3760404586792,24.424842834472656,2.004497528076172],[13.497713088989258,28.78687858581543,11.432450294494629],[10.018567085266113,25.104841232299805,4.184566020965576],[5.7783002853393555,20.61729621887207,11.432450294494629],[5.7783002853393555,20.61729621887207,11.432450294494629],[10.018567085266113,25.104841232299805,4.184566020965576],[9.82309627532959,24.89797019958496,4.07915735244751],[5.7783002853393555,20.61729621887207,11.432450294494629],[9.82309627532959,24.89797019958496,4.07915735244751],[9.646199226379395,24.710758209228516,3.918613910675049],[13.497713088989258,28.78687858581543,-18.16754913330078],[11.285896301269531,26.446075439453125,2.4305026531219482],[13.497713088989258,28.78687858581543,11.432450294494629],[13.497713088989258,28.78687858581543,11.432450294494629],[11.285896301269531,26.446075439453125,2.4305026531219482],[11.306984901428223,26.468393325805664,2.732450485229492],[13.497713088989258,28.78687858581543,11.432450294494629],[11.306984901428223,26.468393325805664,2.732450485229492],[11.285896301269531,26.446075439453125,3.034398078918457],[11.285896301269531,26.446075439453125,3.034398078918457],[11.223495483398438,26.380035400390625,3.323984146118164],[13.497713088989258,28.78687858581543,11.432450294494629],[13.497713088989258,28.78687858581543,11.432450294494629],[11.223495483398438,26.380035400390625,3.323984146118164],[11.122335433959961,26.272977828979492,3.589352607727051],[13.497713088989258,28.78687858581543,11.432450294494629],[11.122335433959961,26.272977828979492,3.589352607727051],[10.986559867858887,26.129281997680664,3.8196394443511963],[10.986559867858887,26.129281997680664,3.8196394443511963],[10.821724891662598,25.954835891723633,4.0054168701171875],[13.497713088989258,28.78687858581543,11.432450294494629],[13.497713088989258,28.78687858581543,11.432450294494629],[10.821724891662598,25.954835891723633,4.0054168701171875],[10.634581565856934,25.756778717041016,4.139078617095947],[13.497713088989258,28.78687858581543,11.432450294494629],[10.634581565856934,25.756778717041016,4.139078617095947],[10.432788848876953,25.5432186126709,4.215152740478516],[10.432788848876953,25.5432186126709,4.215152740478516],[10.224610328674316,25.322898864746094,4.230525016784668],[13.497713088989258,28.78687858581543,11.432450294494629],[13.497713088989258,28.78687858581543,11.432450294494629],[10.224610328674316,25.322898864746094,4.230525016784668],[10.018567085266113,25.104841232299805,4.184566020965576],[9.646199226379395,24.710758209228516,3.918613910675049],[9.495119094848633,24.550867080688477,3.7095091342926025],[5.7783002853393555,20.61729621887207,11.432450294494629],[5.7783002853393555,20.61729621887207,11.432450294494629],[9.495119094848633,24.550867080688477,3.7095091342926025],[9.3760404586792,24.424842834472656,3.4604032039642334],[5.7783002853393555,20.61729621887207,11.432450294494629],[9.3760404586792,24.424842834472656,3.4604032039642334],[9.293838500976562,24.337846755981445,3.181494951248169],[9.293838500976562,24.337846755981445,3.181494951248169],[9.25187873840332,24.293439865112305,2.8842029571533203],[5.7783002853393555,20.61729621887207,11.432450294494629],[5.7783002853393555,20.61729621887207,11.432450294494629],[9.25187873840332,24.293439865112305,2.8842029571533203],[9.25187873840332,24.293439865112305,2.580697774887085],[9.3760404586792,24.424842834472656,2.004497528076172],[9.495119094848633,24.550867080688477,1.7553915977478027],[5.7783002853393555,20.61729621887207,-18.16754913330078],[5.7783002853393555,20.61729621887207,-18.16754913330078],[9.495119094848633,24.550867080688477,1.7553915977478027],[9.646199226379395,24.710758209228516,1.546286702156067],[5.7783002853393555,20.61729621887207,-18.16754913330078],[9.646199226379395,24.710758209228516,1.546286702156067],[9.82309627532959,24.89797019958496,1.385743498802185],[9.82309627532959,24.89797019958496,1.385743498802185],[10.018567085266113,25.104841232299805,1.280334711074829],[5.7783002853393555,20.61729621887207,-18.16754913330078],[10.432788848876953,25.5432186126709,1.2497478723526],[10.634581565856934,25.756778717041016,1.325822114944458],[13.497713088989258,28.78687858581543,-18.16754913330078],[13.497713088989258,28.78687858581543,-18.16754913330078],[10.634581565856934,25.756778717041016,1.325822114944458],[10.821724891662598,25.954835891723633,1.4594839811325073],[13.497713088989258,28.78687858581543,-18.16754913330078],[10.821724891662598,25.954835891723633,1.4594839811325073],[10.986559867858887,26.129281997680664,1.6452611684799194],[10.986559867858887,26.129281997680664,1.6452611684799194],[11.122335433959961,26.272977828979492,1.875548005104065],[13.497713088989258,28.78687858581543,-18.16754913330078],[13.497713088989258,28.78687858581543,-18.16754913330078],[11.122335433959961,26.272977828979492,1.875548005104065],[11.223495483398438,26.380035400390625,2.140916585922241],[13.497713088989258,28.78687858581543,-18.16754913330078],[11.223495483398438,26.380035400390625,2.140916585922241],[11.285896301269531,26.446075439453125,2.4305026531219482],[18.725351333618164,32.08687973022461,-18.16754913330078],[18.725351333618164,28.78687858581543,-18.16754913330078],[18.725351333618164,32.08687973022461,11.432450294494629],[18.725351333618164,32.08687973022461,11.432450294494629],[18.725351333618164,28.78687858581543,-18.16754913330078],[18.725351333618164,28.78687858581543,11.432450294494629],[18.725351333618164,28.78687858581543,-18.16754913330078],[13.497713088989258,28.78687858581543,-18.16754913330078],[18.725351333618164,28.78687858581543,11.432450294494629],[18.725351333618164,28.78687858581543,11.432450294494629],[13.497713088989258,28.78687858581543,-18.16754913330078],[13.497713088989258,28.78687858581543,11.432450294494629] ],
faces=[[0,1,2],[3,4,5],[6,7,8],[9,10,11],[12,13,14],[15,16,17],[18,19,20],[21,22,23],[24,25,26],[27,28,29],[30,31,32],[33,34,35],[36,37,38],[39,40,41],[42,43,44],[45,46,47],[48,49,50],[51,52,53],[54,55,56],[57,58,59],[60,61,62],[63,64,65],[66,67,68],[69,70,71],[72,73,74],[75,76,77],[78,79,80],[81,82,83],[84,85,86],[87,88,89],[90,91,92],[93,94,95],[96,97,98],[99,100,101],[102,103,104],[105,106,107],[108,109,110],[111,112,113],[114,115,116],[117,118,119],[120,121,122],[123,124,125],[126,127,128],[129,130,131],[132,133,134],[135,136,137],[138,139,140],[141,142,143],[144,145,146],[147,148,149],[150,151,152],[153,154,155],[156,157,158],[159,160,161],[162,163,164],[165,166,167],[168,169,170],[171,172,173],[174,175,176],[177,178,179],[180,181,182],[183,184,185],[186,187,188],[189,190,191],[192,193,194],[195,196,197],[198,199,200],[201,202,203],[204,205,206],[207,208,209],[210,211,212],[213,214,215],[216,217,218],[219,220,221],[222,223,224],[225,226,227],[228,229,230],[231,232,233],[234,235,236],[237,238,239],[240,241,242],[243,244,245],[246,247,248],[249,250,251],[252,253,254],[255,256,257],[258,259,260],[261,262,263],[264,265,266],[267,268,269],[270,271,272],[273,274,275],[276,277,278],[279,280,281],[282,283,284],[285,286,287],[288,289,290],[291,292,293],[294,295,296],[297,298,299],[300,301,302],[303,304,305],[306,307,308],[309,310,311],[312,313,314],[315,316,317],[318,319,320],[321,322,323],[324,325,326],[327,328,329],[330,331,332],[333,334,335],[336,337,338],[339,340,341],[342,343,344],[345,346,347],[348,349,350],[351,352,353],[354,355,356],[357,358,359],[360,361,362],[363,364,365],[366,367,368],[369,370,371],[372,373,374],[375,376,377],[378,379,380],[381,382,383],[384,385,386],[387,388,389],[390,391,392],[393,394,395],[396,397,398],[399,400,401],[402,403,404],[405,406,407],[408,409,410],[411,412,413],[414,415,416],[417,418,419],[420,421,422],[423,424,425],[426,427,428],[429,430,431],[432,433,434],[435,436,437],[438,439,440],[441,442,443],[444,445,446],[447,448,449],[450,451,452],[453,454,455],[456,457,458],[459,460,461],[462,463,464],[465,466,467],[468,469,470],[471,472,473],[474,475,476],[477,478,479],[480,481,482],[483,484,485],[486,487,488],[489,490,491],[492,493,494],[495,496,497],[498,499,500],[501,502,503],[504,505,506],[507,508,509],[510,511,512],[513,514,515],[516,517,518],[519,520,521],[522,523,524],[525,526,527],[528,529,530],[531,532,533],[534,535,536],[537,538,539],[540,541,542],[543,544,545],[546,547,548],[549,550,551],[552,553,554],[555,556,557],[558,559,560],[561,562,563],[564,565,566],[567,568,569],[570,571,572],[573,574,575],[576,577,578],[579,580,581],[582,583,584],[585,586,587],[588,589,590],[591,592,593],[594,595,596],[597,598,599],[600,601,602],[603,604,605],[606,607,608],[609,610,611],[612,613,614],[615,616,617],[618,619,620],[621,622,623],[624,625,626],[627,628,629],[630,631,632],[633,634,635],[636,637,638],[639,640,641],[642,643,644],[645,646,647],[648,649,650],[651,652,653],[654,655,656],[657,658,659],[660,661,662],[663,664,665],[666,667,668],[669,670,671],[672,673,674],[675,676,677],[678,679,680],[681,682,683],[684,685,686],[687,688,689],[690,691,692],[693,694,695],[696,697,698],[699,700,701],[702,703,704],[705,706,707],[708,709,710],[711,712,713],[714,715,716],[717,718,719],[720,721,722],[723,724,725],[726,727,728],[729,730,731],[732,733,734],[735,736,737],[738,739,740],[741,742,743],[744,745,746],[747,748,749],[750,751,752],[753,754,755],[756,757,758],[759,760,761],[762,763,764],[765,766,767],[768,769,770],[771,772,773],[774,775,776],[777,778,779],[780,781,782],[783,784,785],[786,787,788],[789,790,791],[792,793,794],[795,796,797],[798,799,800],[801,802,803],[804,805,806],[807,808,809],[810,811,812],[813,814,815],[816,817,818],[819,820,821],[822,823,824],[825,826,827],[828,829,830],[831,832,833],[834,835,836],[837,838,839],[840,841,842],[843,844,845],[846,847,848],[849,850,851],[852,853,854],[855,856,857],[858,859,860],[861,862,863],[864,865,866],[867,868,869],[870,871,872],[873,874,875],[876,877,878],[879,880,881],[882,883,884],[885,886,887],[888,889,890],[891,892,893],[894,895,896],[897,898,899]]);}